@@ -40,7 +40,7 @@ static int sockopt_callback(void *clientp, curl_socket_t curlfd,
   (void) clientp;
   (void) purpose;
   setsockopt(curlfd, SOL_SOCKET, SO_SNDBUF,
-             (const char *)&sndbufsize, sizeof(sndbufsize));
+             (char *)&sndbufsize, sizeof(sndbufsize));
 #else
   (void)clientp;
   (void)curlfd;
@@ -49,9 +49,9 @@ static int sockopt_callback(void *clientp, curl_socket_t curlfd,
   return CURL_SOCKOPT_OK;
 }
 
-int test(char *URL)
+CURLcode test(char *URL)
 {
-  CURLcode code;
+  CURLcode code = TEST_ERR_MAJOR_BAD;
   CURLcode res;
   struct curl_slist *pHeaderList = NULL;
   CURL *curl = curl_easy_init();
@@ -92,10 +92,10 @@ int test(char *URL)
   else {
     printf("curl_easy_perform() failed. e = %d\n", code);
   }
-  test_cleanup:
+test_cleanup:
   curl_slist_free_all(pHeaderList);
   curl_easy_cleanup(curl);
   curl_global_cleanup();
 
-  return 0;
+  return code;
 }
